
/* The purpose of this function is to return the index of the sidebar accordion which should be opened by default.
   This function uses param "key" as a lookup into the "accordions" array. If it finds a match,
   it will then determine whether one of associated "urls" is part of the location.href. If so, it returns the index 
   of that url. This index determines which accordion is expanded on the page. We have multiple 
   nested accordions, nd each one corresponds to an entry in the "accordions" var below.
*/
function autoExpand(key)
{
    var accordions = [ { key: "top_level", urls: [ "general", "guides", "prog_guide", "api_ref" ] },
                       { key: "prog_guide/01", urls: [ "prog_guide/01" ] },
                       { key: "prog_guide/02", urls: [ "prog_guide/02" ] },
                       { key: "prog_guide/03", urls: [ "prog_guide/03" ] },
                       { key: "prog_guide/04", urls: [ "prog_guide/04" ] },
                       { key: "prog_guide/05", urls: [ "prog_guide/05" ] },
                       { key: "prog_guide/06", urls: [ "prog_guide/06" ] },
                       { key: "prog_guide/07", urls: [ "prog_guide/07" ] },
                       { key: "prog_guide/08", urls: [ "prog_guide/08" ] },
                       { key: "prog_guide/09", urls: [ "prog_guide/09" ] },
                       { key: "prog_guide/10", urls: [ "prog_guide/10" ] },
                       { key: "prog_guide/12", urls: [ "prog_guide/12" ] },
                       { key: "prog_guide/appendix", urls: [ "prog_guide/appendix" ] },
                       { key: "api_ref", urls: [ "api_ref" ] },
                       { key: "/guides/0", urls: [ "/guides/0" ] },
    ];
    
    for (var i = 0; i < accordions.length; i++)
    {
        if (key == accordions[i].key)
        {
            for (var j = 0; j < accordions[i].urls.length; j++)
            {
                if (location.href.includes(accordions[i].urls[j]))
                {
                    return j;
                }
            }
        }
    }
       
    return false;
}

// Returns true if the API search box should be visible. This is true for all api_ref pages.
function showAPISearch()
{
    if (location.href.includes("api_ref"))
    {
        return true;
    }
    
    return false;
}

// Not all possible URLs have an entry in the sidebar. For these, we need to
// come up with a substitute. For example, the class pages 
// don't have individual menu entries. So this function provides a substitute
// so the code can highlight an appropriate entry in the sidebar and the breadcrumbs 
// will work.
function findSubstituteLeafAnchor()
{
    // this array means any URL which contains an orphans.url value will be correlated with the url in orphans.home
    var orphans = [ { url: "api_ref/cpp/class", home: "build/api_ref/cpp/classes.html" },
                    { url: "api_ref/cs/class", home: "build/api_ref/cs/classes.html" }
    ];
    
    for (var i = 0 ; i < orphans.length; i++)
    {
        if (location.href.includes(orphans[i].url))
        {
            var anchors = $( "#accordion_panel" ).find("a");
            
            for (var j = 0; j < anchors.length; j++)
            {
                pos = anchors[j].href.search("build");
                
                if (pos == -1) continue; // something unexpected. ignore.
                
                currentUrl = anchors[j].href.substring(pos);
                
                if (currentUrl === orphans[i].home)
                {
                    return anchors[j];
                }
            }
        }
    }
    
    // this should never happen, but returning empty so we don't ever run into a null issue
    return "";
}

// on some pages, breadcrumbs are not appropriate. test before generating.
function shouldGenerateBreadcrumbs()
{
    if (location.href.includes("main-landing.html") || 
        location.href.includes("/misc/") ||
        location.href.includes("api_ref"))
    {
        return false;
    }
    
    return true;
}